@@ -2,11 +2,12 @@ import importlib
 import xml.etree.ElementTree as ET
 
 from marshmallow import EXCLUDE
+from marshmallow import Schema
 from marshmallow import fields
 from marshmallow import post_load
 from marshmallow import pre_load
-from marshmallow import Schema
-from patent_client.util.manager import resolve
+
+from patent_client.util.base.manager import resolve
 
 # from .model import ITCInvestigation, ITCDocument, ITCAttachment
 
