@@ -1,17 +1,20 @@
 from __future__ import annotations
 
 import datetime
-from collections import OrderedDict
 from dataclasses import dataclass
 from dataclasses import field
-from typing import List
-from typing import Optional
 
 from patent_client import session
 from patent_client.util import Model
+from patent_client.util import ListManager
 from patent_client.util import one_to_many
 from patent_client.util import one_to_one
-from patent_client.util import QuerySet
+
+
+@dataclass
+class AssignmentPage:
+    num_found: int
+    docs: "List[Assignment]" = field(default_factory=ListManager)
 
 
 @dataclass
@@ -22,15 +25,15 @@ class Assignment(Model):
     last_update_date: str
     page_count: int
     recorded_date: datetime.date
-    corr_name: str
-    corr_address: str
-    assignors: QuerySet[Assignor]
-    assignees: QuerySet[Assignee]
-    properties: QuerySet[Property] = field(repr=False)
+    corr_name: str = None
+    corr_address: str = None
+    assignors: "QuerySet[Assignor]" = field(default_factory=ListManager)
+    assignees: "QuerySet[Assignee]" = field(default_factory=ListManager)
+    properties: "QuerySet[Property]" = field(repr=False, default_factory=ListManager)
     """Properties objects associated with this Assignment"""
-    assignment_record_has_images: bool
-    transaction_date: Optional[datetime.date] = None
-    date_produced: Optional[datetime.date] = None
+    assignment_record_has_images: bool = False
+    transaction_date: "Optional[datetime.date]" = None
+    date_produced: "Optional[datetime.date]" = None
 
     @property
     def _image_url(self):
@@ -48,46 +51,35 @@ class Assignment(Model):
 
 @dataclass
 class Property(Model):
-    invention_title: str
-    inventors: str
-    # Numbers
     appl_id: str
-    pct_num: str
-    intl_reg_num: str
-    publ_num: str
-    pat_num: str
+    invention_title: "Optional[str]" = None
+    inventors: "Optional[str]" = None
+    # Numbers
+    pct_num: "Optional[str]" = None
+    intl_reg_num: "Optional[str]" = None
+    publ_num: "Optional[str]" = None
+    pat_num: "Optional[str]" = None
     # Dates
-    filing_date: datetime.date
-    intl_publ_date: datetime.date
-    issue_date: datetime.date
-    publ_date: datetime.date
+    filing_date: "Optional[datetime.date]" = None
+    intl_publ_date: "Optional[datetime.date]" = None
+    issue_date: "Optional[datetime.date]" = None
+    publ_date: "Optional[datetime.date]" = None
+
+    def __repr__(self):
+        return f"Property(appl_id={self.appl_id}, invention_title={self.invention_title})"
 
     us_application = one_to_one("patent_client.USApplication", appl_id="appl_id")
     """A USApplication object related to the property"""
 
 
-@dataclass
-class Person(Model):
-    name: str
-    address: str
-    city: str
-    state: str
-    post_code: str
-    country_name: str
-
-
 @dataclass
 class Assignor(Model):
     name: str
     ex_date: datetime.date
-    date_ack: datetime.datetime
+    date_ack: datetime.datetime = None
 
 
 @dataclass
 class Assignee(Model):
     name: str
-    address: str
-    city: str
-    state: str
-    country_name: str
-    postcode: str
+    address: "Optional[str]" = None
